API
===

.. autoclass:: riskmatrix.RiskMatrix
    :members:

.. autoclass:: riskmatrix.Axis
    :members:

.. autoclass:: riskmatrix.AxisPoint
    :members:

.. autoclass:: riskmatrix.Category
    :members:

.. autoclass:: riskmatrix.Coordinate
    :members:
